@@ -16,8 +16,8 @@ use std::sync::Arc;
 use wasmer_engine::{Export, ExportFunction, ExportFunctionMetadata};
 use wasmer_vm::{
     raise_user_trap, resume_panic, wasmer_call_trampoline, ImportInitializerFuncPtr,
-    VMDynamicFunctionContext, VMFuncRef, VMFunction, VMFunctionBody, VMFunctionEnvironment,
-    VMFunctionKind, VMTrampoline,
+    VMCallerCheckedAnyfunc, VMDynamicFunctionContext, VMFuncRef, VMFunction, VMFunctionBody,
+    VMFunctionEnvironment, VMFunctionKind, VMTrampoline,
 };
 
 /// A WebAssembly `function` instance.
@@ -551,6 +551,16 @@ impl Function {
         }
     }
 
+    pub(crate) fn vm_funcref(&self) -> VMFuncRef {
+        let engine = self.store.engine();
+        let vmsignature = engine.register_signature(&self.exported.vm_function.signature);
+        engine.register_function_metadata(VMCallerCheckedAnyfunc {
+            func_ptr: self.exported.vm_function.address,
+            type_index: vmsignature,
+            vmctx: self.exported.vm_function.vmctx,
+        })
+    }
+
     /// Transform this WebAssembly function into a function with the
     /// native ABI. See [`NativeFunc`] to learn more.
     ///
@@ -1462,7 +1472,7 @@ mod inner {
 
         #[test]
         fn test_into_array() {
-            assert_eq!(().into_array(), []);
+            assert_eq!(().into_array(), [0i128; 0]);
             assert_eq!((1).into_array(), [1]);
             assert_eq!((1i32, 2i64).into_array(), [1, 2]);
             assert_eq!(
